@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Announce
 #
-# $Id: lonannounce.pm,v 1.64 2006/12/06 21:52:49 albertel Exp $
+# $Id: lonannounce.pm,v 1.65 2006/12/20 22:36:17 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -90,7 +90,7 @@ sub readcalendar {
 	$navmap = Apache::lonnavmaps::navmap->new();
     }
     my %resourcedata=
-	&Apache::lonnet::dump('resourcedata',$coursedom,$coursenum);
+	&Apache::lonnet::get_courseresdata($coursenum,$coursedom);
     foreach my $thiskey (sort keys %resourcedata) {
 	if ($resourcedata{$thiskey.'.type'}=~/^date/) {
 	    my ($course,$middle,$part,$name)=
