@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Create a user
 #
-# $Id: loncreateuser.pm,v 1.141 2006/12/01 21:52:29 albertel Exp $
+# $Id: loncreateuser.pm,v 1.142 2006/12/21 21:40:28 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1394,7 +1394,7 @@ END
 		        $r->print(&Apache::loncommon::commit_customrole($udom,$uname,$securl,$three,$four,$five,$start,$end));
                     }
                 }
-	    } elsif ($key=~/^form\.act\_($match_domain)\_($match_courseid)\_([^\_]+)$/) {
+	    } elsif ($key=~/^form\.act\_($match_domain)\_($match_name)\_([^\_]+)$/) {
 		# Activate roles for sections with 3 id numbers
 		# set start, end times, and the url for the class
 		my ($one,$two,$three)=($1,$2,$3);
