@@ -1,5 +1,5 @@
 #
-# $Id: lonsupportreq.pm,v 1.39 2006/12/06 22:22:37 albertel Exp $
+# $Id: lonsupportreq.pm,v 1.41 2006/12/21 18:32:54 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -83,20 +83,59 @@ sub print_request_form {
     $usec = $env{'request.course.sec'};
     $cid = $env{'request.course.id'};
     $formname = 'logproblem';
-    if ($origurl =~ m-^http://-) {
+    my $machine = &Apache::lonnet::absolute_url();
+    if ($origurl =~ m-^https?://-) {
         $server = $origurl;
     } else {
-        $server = 'http://'.$ENV{'SERVER_NAME'}.$origurl;
+        $server = $machine.$origurl;
     }
-    my $scripttag = (<<'END');
+    my %lt = &Apache::lonlocal::texthash (
+                  email => 'The e-mail address you entered',
+                  notv => 'is not a valid e-mail address',
+                  rsub => 'You must include a subject',
+                  rdes => 'You must include a description',
+                  name => 'Name',
+                  subm => 'Submit Request',
+                  emad => 'E-mail address',
+                  unme => 'username',
+                  doma => 'domain',
+                  entr => 'Enter the username you use to log-in to your LON-CAPA system, and choose your domain.',
+                  urlp => 'URL of page',
+                  phon => 'Phone',
+                  crsd => 'Course Details',
+                  enin => 'Enter institutional course code',
+                  pick => 'Pick',
+                  enct => 'Enter course title',
+                  secn => 'Section Number',
+                  sele => 'Select',
+                  titl => 'Title',
+                  lsec => 'LON-CAPA sec',
+                  subj => 'Subject',
+                  detd => 'Detailed Description',
+                  opfi => 'Optional file upload',
+                  uplf => 'Upload a file (e.g., a screenshot) relevant to your support request (128 KB max. size)',
+                  fini => 'Finish',
+                  clfm => 'Clear Form',
+    );
+    my $scripttag = (<<"END");
 function validate() {
     if (validmail(document.logproblem.email) == false) {
-        alert("The e-mail address you entered: "+document.logproblem.email.value+" is not a valid e-mail address.");
+        alert("$lt{'email'}: "+document.logproblem.email.value+" $lt{'notv'}.");
+        return;
+    }
+    if (document.logproblem.subject.value == '') {
+        alert("$lt{'rsub'}.");
+        return;
+    }
+    if (document.logproblem.description.value == '') {
+        alert("$lt{'rdes'}.");
         return;
     }
     document.logproblem.submit();
 }
 
+END
+    $scripttag .= <<'END';
 function validmail(field) {
     var str = field.value;
     if (window.RegExp) {
@@ -120,7 +159,7 @@ function validmail(field) {
 END
 
     if ($cid =~ m/_/) {
-        ($cdom,$cnum) = split/_/,$cid;
+        ($cdom,$cnum) = split(/_/,$cid);
     }
     if ($cdom && $cnum) {
         my %csettings = &Apache::lonnet::get('environment',['description','internal.coursecode','internal.sectionnums'],$cdom,$cnum);
@@ -140,10 +179,10 @@ END
     if ($env{'environment.firstname'}) {
         $firstname = $env{'environment.firstname'};
     }
-    my @sections = split/,/,$sectionlist;
-    my %groupid = ();
-    foreach (@sections) {
-        my ($sec,$grp) = split/:/,$_;
+    my @sections = split(/,/,$sectionlist);
+    my %groupid;
+    foreach my $section (@sections) {
+        my ($sec,$grp) = split(/:/,$section);
         $groupid{$sec} = $grp;
     }
     my $codedom = $Apache::lonnet::perlvar{'lonDefDomain'};
@@ -155,14 +194,14 @@ END
     if ($codedom) {
         $details_title = '<br />('.$codedom.')';
     }
-    my %coursecodes = ();
-    my %codes = ();
-    my @codetitles = ();
-    my %cat_titles = ();
-    my %cat_order = ();
-    my %idlist = ();
-    my %idnums = ();
-    my %idlist_titles = ();
+    my %coursecodes;
+    my %codes;
+    my @codetitles;
+    my %cat_titles;
+    my %cat_order;
+    my %idlist;
+    my %idnums;
+    my %idlist_titles;
     my $caller = 'global';
     my $totcodes = 0;
     my $format_reply;
@@ -236,7 +275,7 @@ function initialize_codes() {
             <td width="140" bgcolor="$tablecolor">
              <table width="140" border="0" cellpadding="8" cellspacing="0">
               <tr>
-               <td align="right"><b>Name:</b>
+               <td align="right"><b>$lt{'name'}:</b>
                </td>
               </tr>
              </table>
@@ -259,7 +298,7 @@ END
         $r->print('<input type="text" size="20" name="username" value="'.$fullname.'" />');
     }
     $r->print(<<END);
-                &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<input type="button" value="Submit Request" onClick="validate()" />&nbsp;
+                &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<input type="button" value="$lt{'subm'}" onClick="validate()" />&nbsp;
                </td>
               </tr>
              </table>
@@ -274,7 +313,7 @@ END
             <td width="140" bgcolor="$tablecolor">
              <table width="140" border="0" cellpadding="8" cellspacing="0">
               <tr>
-               <td align="right"><b>E-mail address:</b>
+               <td align="right"><b>$lt{'emad'}:</b>
                </td>
               </tr>
              </table>
@@ -298,7 +337,7 @@ END
             <td width="140" bgcolor="$tablecolor">
              <table width="140" border="0" cellpadding="8" cellspacing="0">
               <tr>
-               <td align="right"><b>username/domain:</b>
+               <td align="right"><b>$lt{'unme'}/$lt{'doma'}:</b>
                </td>
               </tr>
              </table>
@@ -311,23 +350,23 @@ END
     my $udom_input = '<input type="hidden" name="udom" value="'.$udom.'" />';
     my $uname_input = '<input type="hidden" name="uname" value="'.$uname.'" />'; 
     if (defined($uname) && defined($udom)) {
-        $r->print('<i>username</i>:&nbsp;'.$uname.'&nbsp;&nbsp;<i>domain</i>:&nbsp;'.$udom.$udom_input.$uname_input);
+        $r->print('<i>'.$lt{'unme'}.'</i>:&nbsp;'.$uname.'&nbsp;&nbsp;<i>'.$lt{'doma'}.'</i>:&nbsp;'.$udom.$udom_input.$uname_input);
     } else {
         my $udomform = '';
         my $unameform = '';
         if (defined($udom)) {
-            $udomform = '<i>domain</i>:&nbsp;'.$udom.$udom_input;
+            $udomform = '<i>'.$lt{'doma'}.'</i>:&nbsp;'.$udom.$udom_input;
         } elsif (defined($uname)) {
-            $unameform = '<i>username</i>:&nbsp;'.$uname.'&nbsp;&nbsp;'.$uname_input;
+            $unameform = '<i>'.$lt{'unme'}.'</i>:&nbsp;'.$uname.'&nbsp;&nbsp;'.$uname_input;
         }
         if ($udomform eq '') {
-            $udomform = '<i>domain</i>:&nbsp;';
+            $udomform = '<i>'.$lt{'doma'}.'</i>:&nbsp;';
             $udomform .= &Apache::loncommon::select_dom_form($codedom,'udom');
         }
         if ($unameform eq '') {
-            $unameform= '<i>username</i>:&nbsp;<input type="text" size="12" name="uname" value="'.$uname.'" />&nbsp;&nbsp;';
+            $unameform= '<i>'.$lt{'unme'}.'</i>:&nbsp;<input type="text" size="12" name="uname" value="'.$uname.'" />&nbsp;&nbsp;';
         }
-        $r->print($unameform.$udomform.'<br />Enter the username you use to log-in to your LON-CAPA system, and choose your domain.');
+        $r->print($unameform.$udomform.'<br />'.$lt{'entr'});
     }
     $r->print(<<END);
                </td>
@@ -344,7 +383,7 @@ END
             <td width="140" bgcolor="$tablecolor">
              <table width="140" border="0" cellpadding="8" cellspacing="0">
               <tr>
-               <td align="right"><b>URL of page:</b>
+               <td align="right"><b>$lt{'urlp'}:</b>
                </td>
               </tr>
              </table>
@@ -368,7 +407,7 @@ END
             <td width="140" bgcolor="$tablecolor">
              <table width="140" border="0" cellpadding="8" cellspacing="0">
               <tr>
-               <td align="right"><b>Phone #:</b>
+               <td align="right"><b>$lt{'phon'} #:</b>
                </td>
               </tr>
              </table>
@@ -392,7 +431,7 @@ END
             <td width="140" bgcolor="$tablecolor">
              <table width="140" border="0" cellpadding="8" cellspacing="0">
               <tr>
-               <td align="right"><b>Course Details:</b>$details_title
+               <td align="right"><b>$lt{'crsd'}:</b>$details_title
                </td>
               </tr>
              </table>
@@ -404,19 +443,19 @@ END
 END
     if ($cnum) { 
         if ($coursecodes{$cnum}) {
-            foreach (@codetitles) {
-                $r->print('<i>'.$_.'</i>:&nbsp;'.$codes{$cnum}{$_}.';&nbsp;');
+            foreach my $item (@codetitles) {
+                $r->print('<i>'.$item.'</i>:&nbsp;'.$codes{$cnum}{$item}.';&nbsp;');
             }
             $r->print('&nbsp;<input type="hidden" name="coursecode" value="'.$coursecodes{$cnum}.'" />');
         } else {
-            $r->print('Enter institutional course code:&nbsp;
+            $r->print($lt{'enin'}.':&nbsp;
                   <input type="text" name="coursecode" size="15" value="" />');
         }
     } else {
         if ($totcodes > 0) {
             my $numtitles = @codetitles;
             if ($numtitles == 0) {
-                $r->print('Enter institutional course code:&nbsp;
+                $r->print($lt{'enin'}.':&nbsp;
                   <input type="text" name="coursecode" size="15" value="" />');
             } else {
                 my $lasttitle = $numtitles;
@@ -425,17 +464,17 @@ END
                 } 
                 $r->print('<table><tr><td>'.$codetitles[0].'<br />'."\n".
                       '<select name="'.$codetitles[0].'" onChange="courseSet('."'$codetitles[0]'".')">'."\n".
-                      ' <option value="-1" />Select'."\n");
+                      ' <option value="-1" />'.$lt{'sele'}."\n");
                 my @items = ();
                 my @longitems = ();
                 if ($idlist{$codetitles[0]} =~ /","/) {
-                    @items = split/","/,$idlist{$codetitles[0]};
+                    @items = split(/","/,$idlist{$codetitles[0]});
                 } else {
                     $items[0] = $idlist{$codetitles[0]};
                 }
                 if (defined($idlist_titles{$codetitles[0]})) {
                     if ($idlist_titles{$codetitles[0]} =~ /","/) {
-                        @longitems = split/","/,$idlist_titles{$codetitles[0]};
+                        @longitems = split(/","/,$idlist_titles{$codetitles[0]});
                     } else {
                         $longitems[0] = $idlist_titles{$codetitles[0]};
                     }
@@ -454,7 +493,7 @@ END
                 for (my $i=1; $i<$numtitles; $i++) {
                     $r->print('<td>'.$codetitles[$i].'<br />'."\n".
                      '<select name="'.$codetitles[$i].'" onChange="courseSet('."'$codetitles[$i]'".')">'."\n".
-                     '<option value="-1">&lt;-Pick '.$codetitles[$i-1].'</option>'."\n".
+                     '<option value="-1">&lt;-'.$lt{'pick'}.' '.$codetitles[$i-1].'</option>'."\n".
                      '</select>'."\n".
                      '</td>'
                     );
@@ -463,19 +502,19 @@ END
                 if ($numtitles > 4) {
                     $r->print('<br /><br />'.$codetitles[$numtitles].'<br />'."\n".
                           '<select name="'.$codetitles[$numtitles].'" onChange="courseSet('."'$codetitles[$numtitles]'".')">'."\n".
-                          '<option value="-1">&lt;-Pick '.$codetitles[$numtitles-1].'</option>'."\n".
+                          '<option value="-1">&lt;-'.$lt{'pick'}.' '.$codetitles[$numtitles-1].'</option>'."\n".
                           '</select>'."\n");
                 }
             }
         } else {
-            $r->print('Enter institutional course code:&nbsp;
+            $r->print($lt{'enin'}.':&nbsp;
                   <input type="text" name="coursecode" size="15" value="" />');
         }
     }
     if ($ctitle) {
-        $r->print('<br /><i>Title</i>:&nbsp;'.$ctitle.'<input type="hidden" name="title" value="'.$ctitle.'" />');
+        $r->print('<br /><i>'.$lt{'titl'}.'</i>:&nbsp;'.$ctitle.'<input type="hidden" name="title" value="'.$ctitle.'" />');
     } else {
-        $r->print('<br />Enter course title:&nbsp;
+        $r->print('<br />'.$lt{'enct'}.':&nbsp;
                  <input type="text" name="title" size="25" value="" />');
     }
     $r->print(<<END);
@@ -493,7 +532,7 @@ END
             <td width="140" bgcolor="$tablecolor">
              <table width="140" border="0" cellpadding="8" cellspacing="0">
               <tr>
-               <td align="right"><b>Section Number: </b>
+               <td align="right"><b>$lt{'secn'}: </b>
                </td>
               </tr>
              </table>
@@ -505,12 +544,12 @@ END
 END
     if ($sectionlist) {
         $r->print("<select name=\"section\"\n>".
-                  "  <option value=\"\" selected=\"selected\">Select</option>\n");
-        foreach (sort keys %groupid) {
-            if ($_ eq $groupid{$_} || $groupid{$_} eq '') {
-                $r->print("  <option value=\"$_\" >$_</option>\n");
+                  "  <option value=\"\" selected=\"selected\">$lt{'sele'}</option>\n");
+        foreach my $id (sort(keys(%groupid))) {
+            if ($id eq $groupid{$id} || $groupid{$id} eq '') {
+                $r->print("  <option value=\"$id\" >$id</option>\n");
             } else {
-                $r->print("  <option value=\"$_\" >$_ - (LON-CAPA sec: $groupid{$_})</option>\n");
+                $r->print("  <option value=\"$id\" >$id - ($lt{'lsec'}: $groupid{$id})</option>\n");
             }
         }
         $r->print("</select>");
@@ -532,7 +571,7 @@ END
             <td width="140" bgcolor="$tablecolor">
              <table width="140" border="0" cellpadding="8" cellspacing="0">
               <tr>
-               <td align="right"><b>Subject</b>
+               <td align="right"><b>$lt{'subj'}</b>
                </td>
               </tr>
              </table>
@@ -556,7 +595,7 @@ END
             <td width="140" bgcolor="$tablecolor">
              <table width="140" border="0" cellpadding="8" cellspacing="0">
               <tr>
-               <td align="right"><b>Detailed description:</b>
+               <td align="right"><b>$lt{'detd'}:</b>
                </td>
               </tr>
              </table>
@@ -583,7 +622,7 @@ END
             <td width="140" bgcolor="$tablecolor">
              <table width="140" border="0" cellpadding="8" cellspacing="0">
               <tr>
-               <td align="right"><b>Optional file upload:</b>
+               <td align="right"><b>$lt{'opfi'}:</b>
                </td>
               </tr>
              </table>
@@ -592,7 +631,7 @@ END
              <table width="100%" border="0" cellpadding="8" cellspacing="0">
               <tr>
                <td>
-                <input type="file" name="screenshot" size="20" /><br />Upload a file (e.g., a screenshot) relevant to your support request (128 KB max. size).
+                <input type="file" name="screenshot" size="20" /><br />$lt{'uplf'}
                </td>
               </tr>
              </table>
@@ -611,7 +650,7 @@ END
             <td width="140" bgcolor="$tablecolor">
              <table width="140" border="0" cellpadding="8" cellspacing="0">
               <tr>
-               <td align="right"><b>Finish:</b>
+               <td align="right"><b>$lt{'fini'}:</b>
                </td>
               </tr>
              </table>
@@ -621,11 +660,11 @@ END
               <tr>
                <td>
                 <input type="hidden" name="action" value="process" />
-                <input type="button" value="Submit Request" onClick="validate()"/> &nbsp;
+                <input type="button" value="$lt{'subm'}" onClick="validate()"/> &nbsp;
                </td>
                <td>&nbsp;</td>
                <td>
-                <input type="reset" value="Clear Form">
+                <input type="reset" value="$lt{'clfm'}">
                </td>
               </tr>
              </table>
@@ -679,30 +718,48 @@ sub print_request_receipt {
             $coursecode .= $env{'form.Number'};
         }
     }
+    my %lt = &Apache::lonlocal::texthash (
+                 name => 'Name',
+                 email => 'Email',
+                 unme => 'Username/domain',
+                 tel => 'Tel',
+                 crsi => 'Course Information',
+                 subj => 'Subject',
+                 desc => 'Description',
+                 date => 'Date/Time',
+                 secn => 'Section',
+                 asup => 'A support request has been sent to',
+                 warn => 'Warning: Problem with support e-mail address',
+                 your => 'Your support request contained the following information',
+                 sect => 'section',
+                 info => 'Information supplied',
+                 adin => 'Additional information recorded',
+    );
+
     my $supportmsg = qq|
-Name: $env{'form.username'}
-Email: $env{'form.email'}
-Username/domain: $env{'form.uname'} - $env{'form.udom'}
-Tel: $env{'form.phone'}
-Course Information: $env{'form.title'} - $coursecode - section: $env{'form.section'}
-Subject: $env{'form.subject'}
-Description: $env{'form.description'}
+$lt{'name'}: $env{'form.username'}
+$lt{'email'}: $env{'form.email'}
+$lt{'unme'}: $env{'form.uname'} - $env{'form.udom'}
+$lt{'tel'}: $env{'form.phone'}
+$lt{'crsi'}: $env{'form.title'} - $coursecode - $lt{'secn'}: $env{'form.section'}
+$lt{'subj'}: $env{'form.subject'}
+$lt{'desc'}: $env{'form.description'}
 URL: $env{'form.sourceurl'}
-Date/Time: $reporttime
+$lt{'date'}: $reporttime
 
     |;
     my $descrip = $env{'form.description'};
     $descrip =~ s#\n#<br />#g;
     my $displaymsg = qq|
-<font color="$fontcolor">Name:</font><font color="$vlinkcolor"> $env{'form.username'}</font><br />
-<font color="$fontcolor">Email: </font><font color="$vlinkcolor">$env{'form.email'}</font><br />
-<font color="$fontcolor">Username/domain: </font><font color="$vlinkcolor">$env{'form.uname'} - $env{'form.udom'}</font><br />
-<font color="$fontcolor">Tel: </font><font color="$vlinkcolor">$env{'form.phone'}</font><br />
-<font color="$fontcolor">Course Information: </font><font color="$vlinkcolor">$env{'form.title'} - $coursecode - section: $env{'form.section'}</font><br />
-<font color="$fontcolor">Subject: </font><font color="$vlinkcolor">$env{'form.subject'}</font><br />
-<font color="$fontcolor">Description: </font><font color="$vlinkcolor">$descrip</font><br />
+<font color="$fontcolor">$lt{'name'}:</font><font color="$vlinkcolor"> $env{'form.username'}</font><br />
+<font color="$fontcolor">$lt{'email'}: </font><font color="$vlinkcolor">$env{'form.email'}</font><br />
+<font color="$fontcolor">$lt{'unme'}: </font><font color="$vlinkcolor">$env{'form.uname'} - $env{'form.udom'}</font><br />
+<font color="$fontcolor">$lt{'tel'}: </font><font color="$vlinkcolor">$env{'form.phone'}</font><br />
+<font color="$fontcolor">$lt{'crsi'}: </font><font color="$vlinkcolor">$env{'form.title'} - $coursecode - $lt{'sect'}: $env{'form.section'}</font><br />
+<font color="$fontcolor">$lt{'subj'}: </font><font color="$vlinkcolor">$env{'form.subject'}</font><br />
+<font color="$fontcolor">$lt{'desc'}: </font><font color="$vlinkcolor">$descrip</font><br />
 <font color="$fontcolor">URL: </font><font color="$vlinkcolor">$env{'form.sourceurl'}</font><br />
-<font color="$fontcolor">Date/Time: </font><font color="$vlinkcolor">$reporttime</font><br />
+<font color="$fontcolor">$lt{'date'}: </font><font color="$vlinkcolor">$reporttime</font><br />
     |;
 
     my $start_page = 
@@ -724,17 +781,15 @@ END
         &print_header($r,$url,'process');
     }
     if ($to =~ m/^[^\@]+\@[^\@]+$/) {
-        $r->print("<h3>A support request has been sent to $to</h3>");
+        $r->print('<h3>'.$lt{'asup'}.' '.$to.'</h3>');
     } else {
         $to = $admin;
         if ($to =~ m/^[^\@]+\@[^\@]+$/) {
-            $r->print("<h3>A support request has been sent to $to</h3>");
-END
+            $r->print('<h3>'.$lt{'asup'}.' '.$to.'</h3>');
         } else {
-            $r->print(<<END);
- <h3>Warning: Problem with support e-mail address</h3>
-As the e-mail address provided for this LON-CAPA server ($to) does not appear to be a valid e-mail address, your support request has <b>not</b> been sent to the LON-CAPA support staff or administrator at your institution. Instead a copy has been sent to the LON-CAPA support team at Michigan State University. 
-END
+            $r->print('
+ <h3>'.$lt{'warn'}.'</h3>'.
+&mt('As the e-mail address provided for this LON-CAPA server ([_1]) does not appear to be a valid e-mail address, your support request has <b>not</b> been sent to the LON-CAPA support staff or administrator at your institution.',$to).' '.&mt('Instead a copy has been sent to the LON-CAPA support team at Michigan State University.')); 
             $to = 'helpdesk@lon-capa.org';
         }
     }
@@ -759,14 +814,14 @@ END
         if ($env{'form.screenshot.filename'}) {
             $attachmentsize = length($env{'form.screenshot'});
             if ($attachmentsize > 131072) {
-                $displaymsg .= "<br />The uploaded screenshot file ($attachmentsize bytes) included with your request exceeded the maximum allowed size - 128 KB, and has therefore been discarded.";
+                $displaymsg .= '<br />'.&mt('The uploaded screenshot file ([_1] bytes) included with your request exceeded the maximum allowed size - 128 KB, and has therefore been discarded.',$attachmentsize);
             } else {
                 $attachmentpath=&Apache::lonnet::userfileupload('screenshot',undef,'helprequests');
             }
         }
     }
 
-    my %cookies = ();
+    my %cookies;
     my $cookie=CGI::Cookie->parse($r->header_in('Cookie'));
     if ($$cookie{'lonID'} =~ /lonID=($LONCAPA::handle_re);/) {
         $cookies{'lonID'} = $1;
@@ -774,16 +829,16 @@ END
 
     if ($attachmentpath =~ m-/([^/]+)$-) {
         $fname = $1;
-        $displaymsg .= "<br />An uploaded screenshot file - $fname ($attachmentsize bytes) was included in the request sent by $env{'user.name'} from LON-CAPA domain: $env{'user.domain'}";
+        $displaymsg .= '<br />'.&mt('An uploaded screenshot file - [_1] ([_2] bytes) was included in the request sent by [_3] from LON-CAPA domain',$fname,$attachmentsize,$env{'user.name'}.': '.$env{'user.domain'});
         $supportmsg .= "\n";
-        foreach (@cookievars) {
-            $supportmsg .= "$_: $cookies{$_}\n";
+        foreach my $var (@cookievars) {
+            $supportmsg .= "$var: $cookies{$var}\n";
         }
-        foreach (@ENVvars) {
-            $supportmsg .= "$_: $ENV{$_}\n";
+        foreach my $var(@ENVvars) {
+            $supportmsg .= "$var: $ENV{$var}\n";
         }
-        foreach (@envvars) {
-            $supportmsg .= "$_: $env{$_}\n";
+        foreach my $var (@envvars) {
+            $supportmsg .= "$var: $env{$var}\n";
         }
     }
  
@@ -804,17 +859,17 @@ END
 
     } else {
         my $envdata = '';
-        foreach (@cookievars) {
-            $envdata .= "$_: $cookies{$_}\n";
+        foreach my $var (@cookievars) {
+            $envdata .= "$var: $cookies{$var}\n";
         }
-        foreach (@ENVvars) {
-            $envdata .= "$_: $ENV{$_}\n";
+        foreach my $var (@ENVvars) {
+            $envdata .= "$var: $ENV{$var}\n";
         }
-        foreach (@envvars) {
-            $envdata .= "$_: $env{$_}\n";
+        foreach my $var (@envvars) {
+            $envdata .= "$var: $env{$var}\n";
         }
-        foreach (@loncvars) {
-            $envdata .= "$_: $env{$_}\n";
+        foreach my $var (@loncvars) {
+            $envdata .= "$var: $env{$var}\n";
         }
         $msg->attach(Type => 'TEXT',
                      Data => $envdata);
@@ -827,7 +882,7 @@ END
         unlink($attachmentpath);
     }
     $r->print(qq|
- <b>Your support request contained the following information</b>:<br /><br />
+ <b>$lt{'your'}</b>:<br /><br />
  <table width="580" border="0" cellpadding="0" cellspacing="0" bgcolor="#000000">
   <tr>
    <td>
@@ -842,7 +897,7 @@ END
             <td width="140" bgcolor="$tablecolor">
              <table width="140" border="0" cellpadding="8" cellspacing="0">
               <tr>
-               <td align="right"><b>Information supplied</b>
+               <td align="right"><b>$lt{'info'}</b>
                </td>
               </tr>
              </table>
@@ -864,7 +919,7 @@ END
             <td width="140" bgcolor="$tablecolor">
              <table width="140" border="0" cellpadding="8" cellspacing="0">
               <tr>
-               <td align="right"><b>Additional information recorded</b>
+               <td align="right"><b>$lt{'adin'}</b>
                </td>
               </tr>
              </table>
@@ -874,19 +929,19 @@ END
               <tr>
                <td>
     |);
-    foreach (@cookievars) {
-        unless($cookies{$_} eq '') {
-            $r->print("$_:&nbsp;<font color='$vlinkcolor'>$cookies{$_}</font>, ");
+    foreach my $var (@cookievars) {
+        unless($cookies{$var} eq '') {
+            $r->print("$var:&nbsp;<font color='$vlinkcolor'>$cookies{$var}</font>, ");
         }
     }
-    foreach (@ENVvars) {
-        unless($ENV{$_} eq '') {
-            $r->print("$_:&nbsp;<font color='$vlinkcolor'>$ENV{$_}</font>, ");
+    foreach my $var (@ENVvars) {
+        unless($ENV{$var} eq '') {
+            $r->print("$var:&nbsp;<font color='$vlinkcolor'>$ENV{$var}</font>, ");
         }
     }
-    foreach (@envvars) {
-        unless($env{$_} eq '') { 
-            $r->print("$_:&nbsp;<font color='$vlinkcolor'>$env{$_}</font>, ");
+    foreach my $var (@envvars) {
+        unless($env{$var} eq '') { 
+            $r->print("$var:&nbsp;<font color='$vlinkcolor'>$env{$var}</font>, ");
         }
     }
     $r->print("
@@ -944,9 +999,9 @@ sub print_header {
          <td>
           <table width="100%" border="0" cellpadding="0" cellspacing="1" bgcolor="#ffffff">
            <tr bgcolor="$tablecolor">
-            <td align="center"><img src="$location/help/gif/smallHelp.gif" border="0" alt="(Login help)" valign="middle" />&nbsp;<b><a href="/adm/loginproblems.html">$lt{'login'}</a></td>
-            <td align="center">&nbsp;<b>$helpdesk_link<img src="$location/lonIcons/helpdesk.gif" border="0" alt="(Ask helpdesk)" valign="middle" />&nbsp;$lt{'ask'}</a></b>&nbsp;</td>$getstartlink
-            <td align="center">&nbsp;<b><a href="$origurl" target="_top"><img src="$location/lonIcons/move_up.gif" border="0" alt="(Back to last location)" valign="middle" />&nbsp;$lt{'back'}</a></b>&nbsp;</td>
+            <td align="center"><img src="$location/help/gif/smallHelp.gif" border="0" alt="($lt{'login'})" valign="middle" />&nbsp;<b><a href="/adm/loginproblems.html">$lt{'login'}</a></td>
+            <td align="center">&nbsp;<b>$helpdesk_link<img src="$location/lonIcons/helpdesk.gif" border="0" alt="($lt{'ask'})" valign="middle" />&nbsp;$lt{'ask'}</a></b>&nbsp;</td>$getstartlink
+            <td align="center">&nbsp;<b><a href="$origurl" target="_top"><img src="$location/lonIcons/move_up.gif" border="0" alt="($lt{'back'})" valign="middle" />&nbsp;$lt{'back'}</a></b>&nbsp;</td>
            </tr>
           </table>
          </td>
