@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # <script> definiton
 #
-# $Id: scripttag.pm,v 1.138 2006/10/17 15:11:37 albertel Exp $
+# $Id: scripttag.pm,v 1.139 2006/12/20 22:41:59 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -133,7 +133,7 @@ sub start_script {
 	    $listing=~s/\\/\\\\/g;
 	    $listing=~s/\'/\\\'/g;
 	    $result.=$listing;
-	    $result.= "</pre>$end_page');newWindow.document.close();newWindow.focus()}
+	    $result.= "<\\/pre>$end_page');newWindow.document.close();newWindow.focus()}
 // ]]>
 </script><a href=\"javascript:LONCAPA_scriptvars_".$uname."_".$udom."_$Apache::lonxml::curdepth();void(0);\">Script Vars</a><br />";
 	}
