@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Page Handler
 #
-# $Id: lonpage.pm,v 1.75 2006/05/30 17:15:10 www Exp $
+# $Id: lonpage.pm,v 1.76 2006/12/12 18:49:27 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -542,7 +542,8 @@ sub handler {
 			  (($nforms>1)?'submit':'hidden').'"></input></form>');
                       }
 		      unless ($target eq 'tex') {
-			  $r->print(&Apache::loncommon::end_page());
+			  $r->print(&Apache::loncommon::end_page({'discussion'
+								      => 1,}));
 		      } else {
 			  $r->print('\end{document}'.$number_of_columns);
 		      }
